pub fn bpf_loader_upgradeable_program_accounts(
program_id: &Pubkey,
elf: &[u8],
rent: &Rent,
) -> [(Pubkey, Account); 2]Expand description
Returns two tuples (Pubkey, Account) for a BPF upgradeable program.
The first tuple is the program account. It contains the provided program ID
and an account with a pointer to its program data account.
The second tuple is the program data account. It contains the program data
address and an account with the program data - a valid BPF Loader Upgradeable
program data account containing the ELF.